@@ -1,6 +1,7 @@
 #m2 plot output
 plot.forestFloor_regression = function(x,
-                                       plot_seq=NULL, 
+                                       plot_seq=NULL,
+                                       plotTest = NULL,
                                        limitY=TRUE,
                                        orderByImportance=TRUE, 
                                        cropXaxes=NULL, 
@@ -26,6 +27,17 @@ plot.forestFloor_regression = function(x,
     userArgs.par  = moreArgs[ parArgs.ind]
   }
   
+  #crop x(forestFloor) object to only visualize test or train
+  plotThese = checkPlotTest(plotTest,x$isTrain)
+  if(!(all(plotThese))) {
+      #cut to those which should be plotted
+    x$FCmatrix = x$FCmatrix[plotThese,]
+    x$Y = x$Y[plotThese]
+    x$X = x$X[plotThese,]
+    if(!is.null(x$FCfit)) x$FCfit = x$FCfit[plotThese,]
+  }
+  
+  
   #short for features and feature contribution in object
   X = x$X
   FCs = x$FCmatrix
@@ -49,7 +61,7 @@ plot.forestFloor_regression = function(x,
     if(is.null(x$FCfit)) x = convolute_ff(x) 
     #retrieve fitted values and compare to actual feature contributions for every variable
   }
-  if(plot_GOF) GOFs = sapply(1:dim(X)[2],function(j) cor(x$FCfit[,j],x$FCmatrix[,j])^2)
+  if(plot_GOF) GOFs = sapply(1:dim(x$FCfit)[2],function(j) cor(x$FCfit[,j],x$FCmatrix[,j])^2)
   
   
   #obsolete
